==> xapian-bindings-1.0.16.tar.gz: xapian-bindings-1.0.16/java/org/xapian/PositionIterator.java <==
/**
 Copyright (c) 2003, Technology Concepts & Design, Inc.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without modification, are permitted
 provided that the following conditions are met:

 - Redistributions of source code must retain the above copyright notice, this list of conditions
 and the following disclaimer.

 - Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 and the following disclaimer in the documentation and/or other materials provided with the distribution.

 - Neither the name of Technology Concepts & Design, Inc. nor the names of its contributors may be used to
 endorse or promote products derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 THE POSSIBILITY OF SUCH DAMAGE.
 **/
package org.xapian;

import org.xapian.errors.XapianError;
import org.xapian.errors.XapianRuntimeError;

import java.util.Iterator;

public class PositionIterator implements Iterator {
    long id = -1;
    private long _end;
    private long _value;

    PositionIterator(long start, long end) {
        id = start;
        _end = end;
    }

    public long getPosition() {
        if (id == -1) throw new XapianRuntimeError("This is an empty PositionIterator");
        return _value;
    }

    public Object next() {
        if (id == -1) throw new XapianRuntimeError("This is an empty PositionIterator");

        try {
            _value = XapianJNI.positioniterator_getvalue(id);
            XapianJNI.positioniterator_next(id);

            return this;
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    public boolean hasNext() {
        if (id == -1) return false;

        try {
            return !XapianJNI.positioniterator_equals(id, _end);
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    public void remove() {
        throw new UnsupportedOperationException("PositionIterator.remove() not supported");
    }

    public String toString() {
        try {
            return XapianJNI.positioniterator_get_description(id);
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    protected void finalize() throws Throwable {
        XapianJNI.positioniterator_finalize(id);
        XapianJNI.positioniterator_finalize(_end);
        super.finalize();
    }

}

==> xapian-bindings-1.2.13.tar.gz: xapian-bindings-1.2.13/java/org/xapian/PositionIterator.java <==
/**
 Copyright (c) 2003, Technology Concepts & Design, Inc.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without modification, are permitted
 provided that the following conditions are met:

 - Redistributions of source code must retain the above copyright notice, this list of conditions
 and the following disclaimer.

 - Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 and the following disclaimer in the documentation and/or other materials provided with the distribution.

 - Neither the name of Technology Concepts & Design, Inc. nor the names of its contributors may be used to
 endorse or promote products derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 THE POSSIBILITY OF SUCH DAMAGE.
 **/
package org.xapian;

import org.xapian.errors.XapianError;
import org.xapian.errors.XapianRuntimeError;

import java.util.Iterator;

public class PositionIterator implements Iterator {
    long id = 0;
    private long _end;
    private long _value;

    PositionIterator(long start, long end) {
        id = start;
        _end = end;
    }

    public long getPosition() {
        if (id == 0) throw new XapianRuntimeError("This is an empty PositionIterator");
        return _value;
    }

    public Object next() {
        if (id == 0) throw new XapianRuntimeError("This is an empty PositionIterator");

        try {
            _value = XapianJNI.positioniterator_getvalue(id);
            XapianJNI.positioniterator_next(id);

            return this;
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    public boolean hasNext() {
        if (id == 0) return false;

        try {
            return !XapianJNI.positioniterator_equals(id, _end);
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    public void remove() {
        throw new UnsupportedOperationException("PositionIterator.remove() not supported");
    }

    public String toString() {
        try {
            return XapianJNI.positioniterator_get_description(id);
        } catch (XapianError xe) {
            throw new XapianRuntimeError(xe);
        }
    }

    protected void finalize() throws Throwable {
        XapianJNI.positioniterator_finalize(id);
        XapianJNI.positioniterator_finalize(_end);
        super.finalize();
    }

}
